import typing

import requests
from pycognito import Cognito

from edilkamin import constants
from edilkamin.utils import get_endpoint, get_headers


def sign_in(username: str, password: str) -> str:
    """Sign in and return token."""
    cognito = Cognito(constants.USER_POOL_ID, constants.CLIENT_ID, username=username)
    cognito.authenticate(password)
    user = cognito.get_user()
    return user._metadata["access_token"]


def device_info(token: str, mac: str) -> typing.Dict:
    """Retrieve device info for a given MAC address in the format `aabbccddeeff`."""
    headers = get_headers(token)
    url = get_endpoint(f"device/{mac}/info")
    response = requests.get(url, headers=headers)
    response.raise_for_status()
    return response.json()


def mqtt_command(token: str, mac_address: str, payload: typing.Dict) -> str:
    """
    Send a MQTT command to the device identified with the MAC address.
    Return the response string.
    """
    headers = get_headers(token)
    url = get_endpoint("mqtt/command")
    data = {"mac_address": mac_address, **payload}
    response = requests.put(url, json=data, headers=headers)
    response.raise_for_status()
    return response.json()


def set_power(token: str, mac_address: str, value: int) -> str:
    """
    Set device power on (1) or off (0).
    Return response string e.g. "Command 0123456789abcdef executed successfully".
    """
    return mqtt_command(token, mac_address, {"name": "power", "value": value})


def set_power_on(token: str, mac_address: str) -> str:
    return set_power(token, mac_address, 1)


def set_power_off(token: str, mac_address: str) -> str:
    return set_power(token, mac_address, 0)



import os

from edilkamin import constants


def get_endpoint(url: str) -> str:
    return constants.BACKEND_URL + url


def get_headers(token: str):
    return {"Authorization": f"Bearer {token}"}


def assert_env(name: str) -> str:
    env = os.environ.get(name)
    assert env
    return env



__all__ = [
    "sign_in",
    "device_info",
    "mqtt_command",
    "set_power",
    "set_power_on",
    "set_power_off",
]
from edilkamin.api import (
    device_info,
    mqtt_command,
    set_power,
    set_power_off,
    set_power_on,
    sign_in,
)



import os
import sys

from setuptools import setup

REQUIRED_PYTHON = (3, 7)


def assert_python_version(version_info):
    current_python = version_info[:2]
    error_message = "Python {}.{} is required, but you're running Python {}.{}"
    error_message = error_message.format(*(REQUIRED_PYTHON + current_python))
    assert current_python >= REQUIRED_PYTHON, error_message


def read(fname):
    with open(os.path.join(os.path.dirname(__file__), fname)) as f:
        return f.read()


# exposing the params so it can be imported
setup_params = {
    "name": "edilkamin",
    "version": "0.2.0",
    "description": "Edilkamin Stove Python client",
    "long_description": read("README.md"),
    "long_description_content_type": "text/markdown",
    "author": "Andre Miras",
    "url": "https://github.com/AndreMiras/edilkamin.py",
    "packages": ["edilkamin"],
    "install_requires": [
        "pycognito",
        "requests",
    ],
    "extras_require": {
        "dev": [
            "black",
            "coveralls",
            "flake8",
            "isort",
            # fixes readthedocs build, refs:
            # https://github.com/readthedocs/readthedocs.org/issues/9038
            "Jinja2<3.1",
            "m2r2",
            "pytest",
            "pytest-cov",
            "Sphinx",
            "sphinx-rtd-theme",
            "tox",
            "twine",
            "wheel",
        ]
    },
}


def run_setup():
    assert_python_version(sys.version_info)
    setup(**setup_params)


# makes sure the setup doesn't run at import time
if __name__ == "__main__":
    run_setup()



#!/usr/bin/env python
from edilkamin.api import device_info, set_power_off, sign_in
from edilkamin.utils import assert_env


def main():
    username = assert_env("USERNAME")
    password = assert_env("PASSWORD")
    mac_address = assert_env("MAC_ADDRESS")
    token = sign_in(username, password)
    info = device_info(token, mac_address)
    print(info)
    result = set_power_off(token, mac_address)
    print(result)


if __name__ == "__main__":
    main()
